@@ -3,8 +3,8 @@ from typing import Optional
 import torch
 from torch import Tensor
 
-from pfhedge._utils.doc import set_attr_and_docstring
-from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.doc import _set_attr_and_docstring
+from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
 from pfhedge.nn.functional import european_payoff
 
@@ -127,11 +127,11 @@ class EuropeanOption(BaseOption):
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_attr_and_docstring(EuropeanOption, "simulate", Derivative.simulate)
-set_attr_and_docstring(EuropeanOption, "to", Derivative.to)
-set_attr_and_docstring(EuropeanOption, "ul", Derivative.ul)
-set_attr_and_docstring(EuropeanOption, "list", Derivative.list)
-set_docstring(EuropeanOption, "payoff", Derivative.payoff)
-set_attr_and_docstring(EuropeanOption, "moneyness", BaseOption.moneyness)
-set_attr_and_docstring(EuropeanOption, "log_moneyness", BaseOption.log_moneyness)
-set_attr_and_docstring(EuropeanOption, "time_to_maturity", BaseOption.time_to_maturity)
+_set_attr_and_docstring(EuropeanOption, "simulate", Derivative.simulate)
+_set_attr_and_docstring(EuropeanOption, "to", Derivative.to)
+_set_attr_and_docstring(EuropeanOption, "ul", Derivative.ul)
+_set_attr_and_docstring(EuropeanOption, "list", Derivative.list)
+_set_docstring(EuropeanOption, "payoff", Derivative.payoff)
+_set_attr_and_docstring(EuropeanOption, "moneyness", BaseOption.moneyness)
+_set_attr_and_docstring(EuropeanOption, "log_moneyness", BaseOption.log_moneyness)
+_set_attr_and_docstring(EuropeanOption, "time_to_maturity", BaseOption.time_to_maturity)
