@@ -3,16 +3,17 @@ from typing import Optional
 import torch
 from torch import Tensor
 
-from pfhedge._utils.doc import set_attr_and_docstring
-from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.doc import _set_attr_and_docstring
+from pfhedge._utils.doc import _set_docstring
+from pfhedge._utils.str import _format_float
+from pfhedge.nn.functional import lookback_payoff
 
-from ...nn.functional import lookback_payoff
 from ..primary.base import Primary
+from .base import BaseOption
 from .base import Derivative
-from .base import OptionMixin
 
 
-class LookbackOption(Derivative, OptionMixin):
+class LookbackOption(BaseOption):
     """A lookback option with fixed strike.
 
     A lookback call option provides its holder the right to buy an underlying with
@@ -45,10 +46,10 @@ class LookbackOption(Derivative, OptionMixin):
         maturity (float, default=20/250): The maturity of the option.
         dtype (torch.dtype, optional): Desired device of returned tensor.
             Default: If None, uses a global default
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
         device (torch.device, optional): Desired device of returned tensor.
             Default: if None, uses the current device for the default tensor type
-            (see ``torch.set_default_tensor_type()``).
+            (see :func:`torch.set_default_tensor_type()`).
             ``device`` will be the CPU for CPU tensor types and
             the current CUDA device for CUDA tensor types.
 
@@ -90,24 +91,24 @@ class LookbackOption(Derivative, OptionMixin):
 
         self.to(dtype=dtype, device=device)
 
-    def __repr__(self) -> str:
-        params = [f"{self.ul().__class__.__name__}(...)"]
+    def extra_repr(self) -> str:
+        params = []
         if not self.call:
-            params.append(f"call={self.call}")
-        params.append(f"strike={self.strike}")
-        params.append(f"maturity={self.maturity:.2e}")
-        params += self.dinfo
-        return self.__class__.__name__ + "(" + ", ".join(params) + ")"
+            params.append("call=" + str(self.call))
+        params.append("strike=" + _format_float(self.strike))
+        params.append("maturity=" + _format_float(self.maturity))
+        return ", ".join(params)
 
     def payoff(self) -> Tensor:
         return lookback_payoff(self.ul().spot, call=self.call, strike=self.strike)
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_attr_and_docstring(LookbackOption, "simulate", Derivative.simulate)
-set_attr_and_docstring(LookbackOption, "to", Derivative.to)
-set_attr_and_docstring(LookbackOption, "ul", Derivative.ul)
-set_docstring(LookbackOption, "payoff", Derivative.payoff)
-set_attr_and_docstring(LookbackOption, "moneyness", OptionMixin.moneyness)
-set_attr_and_docstring(LookbackOption, "log_moneyness", OptionMixin.log_moneyness)
-set_attr_and_docstring(LookbackOption, "time_to_maturity", OptionMixin.time_to_maturity)
+_set_attr_and_docstring(LookbackOption, "simulate", Derivative.simulate)
+_set_attr_and_docstring(LookbackOption, "to", Derivative.to)
+_set_attr_and_docstring(LookbackOption, "ul", Derivative.ul)
+_set_attr_and_docstring(LookbackOption, "list", Derivative.list)
+_set_docstring(LookbackOption, "payoff", Derivative.payoff)
+_set_attr_and_docstring(LookbackOption, "moneyness", BaseOption.moneyness)
+_set_attr_and_docstring(LookbackOption, "log_moneyness", BaseOption.log_moneyness)
+_set_attr_and_docstring(LookbackOption, "time_to_maturity", BaseOption.time_to_maturity)
