@@ -3,8 +3,8 @@ from typing import Optional
 import torch
 from torch import Tensor
 
-from pfhedge._utils.doc import set_attr_and_docstring
-from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.doc import _set_attr_and_docstring
+from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
 from pfhedge.nn.functional import realized_variance
 
@@ -20,7 +20,7 @@ class VarianceSwap(Derivative):
 
     The payoff of a variance swap is given by
 
-    .. math ::
+    .. math::
 
         \\mathrm{payoff} = \\sigma^2 - K
 
@@ -93,8 +93,8 @@ class VarianceSwap(Derivative):
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_attr_and_docstring(VarianceSwap, "simulate", Derivative.simulate)
-set_attr_and_docstring(VarianceSwap, "to", Derivative.to)
-set_attr_and_docstring(VarianceSwap, "ul", Derivative.ul)
-set_attr_and_docstring(VarianceSwap, "list", Derivative.list)
-set_docstring(VarianceSwap, "payoff", Derivative.payoff)
+_set_attr_and_docstring(VarianceSwap, "simulate", Derivative.simulate)
+_set_attr_and_docstring(VarianceSwap, "to", Derivative.to)
+_set_attr_and_docstring(VarianceSwap, "ul", Derivative.ul)
+_set_attr_and_docstring(VarianceSwap, "list", Derivative.list)
+_set_docstring(VarianceSwap, "payoff", Derivative.payoff)
