@@ -7,11 +7,11 @@ from typing import cast
 import torch
 from torch import Tensor
 
-from pfhedge._utils.doc import set_attr_and_docstring
-from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.doc import _set_attr_and_docstring
+from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
+from pfhedge.stochastic import generate_geometric_brownian
 
-from ...stochastic import generate_geometric_brownian
 from .base import Primary
 
 TensorOrFloat = Union[Tensor, float]
@@ -41,7 +41,7 @@ class BrownianStock(Primary):
 
     Buffers:
         - spot (:class:`torch.Tensor`): The spot prices of the instrument.
-          This attribute is set by a method :func:`simulate()`.
+          This attribute is set by a method :meth:`simulate()`.
           The shape is :math:`(N, T)` where
           :math:`N` is the number of simulated paths and
           :math:`T` is the number of time steps.
@@ -118,10 +118,10 @@ class BrownianStock(Primary):
                 the price.
             init_state (tuple[torch.Tensor | float], optional): The initial state of
                 the instrument.
-                This is specified by ``(spot,)``, where ``spot`` is the initial value
-                of the stock price.
+                This is specified by a tuple :math:`(S(0),)` where
+                :math:`spot` is the initial value of the spot price.
                 If ``None`` (default), it uses the default value
-                (See :func:`default_init_state`).
+                (See :attr:`default_init_state`).
                 It also accepts a :class:`float` or a :class:`torch.Tensor`.
 
         Examples:
@@ -157,5 +157,5 @@ class BrownianStock(Primary):
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_docstring(BrownianStock, "default_init_state", Primary.default_init_state)
-set_attr_and_docstring(BrownianStock, "to", Primary.to)
+_set_docstring(BrownianStock, "default_init_state", Primary.default_init_state)
+_set_attr_and_docstring(BrownianStock, "to", Primary.to)
