@@ -1,9 +1,11 @@
+from math import sqrt
+
 import torch
 from torch import Tensor
 
 import pfhedge.autogreek as autogreek
-from pfhedge._utils.bisect import bisect
-from pfhedge._utils.doc import set_attr_and_docstring
+from pfhedge._utils.bisect import find_implied_volatility
+from pfhedge._utils.doc import _set_attr_and_docstring
 from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
@@ -13,25 +15,25 @@ class BSAmericanBinaryOption(BSModuleMixin):
     """Black-Scholes formula for an American Binary Option.
 
     Args:
-        call (bool, default=True): Specifies whether the option is call
-            or put.
+        call (bool, default=True): Specifies whether the option is call or put.
         strike (float, default=1.0): The strike price of the option.
 
     Shape:
         - Input: :math:`(N, *, 4)` where
           :math:`*` means any number of additional dimensions.
-          See :func:`inputs` for the names of input features.
-        - Output: :math:`(N, *, 1)`,
-          all but the last dimension are the same shape as the input.
+          See :meth:`inputs` for the names of input features.
+        - Output: :math:`(N, *, 1)`.
+          All but the last dimension are the same shape as the input.
 
     .. seealso ::
-
         - :class:`pfhedge.nn.BlackScholes`:
           Initialize Black-Scholes formula module from a derivative.
 
-    Examples:
+    References:
+        - Dai, M., 2000. A closed-form solution for perpetual American floating strike
+          lookback options. Journal of Computational Finance, 4(2), pp.63-68.
 
-        The ``forward`` method returns delta of the derivative.
+    Examples:
 
         >>> from pfhedge.nn import BSAmericanBinaryOption
         >>>
@@ -46,10 +48,6 @@ class BSAmericanBinaryOption(BSModuleMixin):
         tensor([[1.1285],
                 [0.0000],
                 [0.0000]])
-
-    References:
-        - Dai, M., 2000. A closed-form solution for perpetual American floating strike
-          lookback options. Journal of Computational Finance, 4(2), pp.63-68.
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
@@ -114,16 +112,15 @@ class BSAmericanBinaryOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         s, m, t, v = map(
             torch.as_tensor,
             (log_moneyness, max_log_moneyness, time_to_maturity, volatility),
         )
 
-        sqrt2 = torch.tensor(2.0).sqrt().item()
-        n1 = self.N.cdf(self.d1(s, t, v) / sqrt2)
-        n2 = self.N.cdf(self.d2(s, t, v) / sqrt2)
+        n1 = self.N.cdf(self.d1(s, t, v) / sqrt(2.0))
+        n2 = self.N.cdf(self.d2(s, t, v) / sqrt(2.0))
 
         p = (1 / 2) * (s.exp() * (1 + n1) + n2)
 
@@ -160,12 +157,11 @@ class BSAmericanBinaryOption(BSModuleMixin):
             (log_moneyness, max_log_moneyness, time_to_maturity, volatility),
         )
 
-        sqrt2 = torch.tensor(2.0).sqrt().item()
         d1 = self.d1(s, t, v)
         d2 = self.d2(s, t, v)
-        c1 = self.N.cdf(d1 / sqrt2)
-        p1 = self.N.log_prob(d1 / sqrt2).exp()
-        p2 = self.N.log_prob(d2 / sqrt2).exp()
+        c1 = self.N.cdf(d1 / sqrt(2.0))
+        p1 = self.N.log_prob(d1 / sqrt(2.0)).exp()
+        p2 = self.N.log_prob(d2 / sqrt(2.0)).exp()
 
         d = (1 + c1 + (p1 + p2)) / (2 * self.strike)
 
@@ -230,19 +226,21 @@ class BSAmericanBinaryOption(BSModuleMixin):
               :math:`*` means any number of additional dimensions.
             - max_log_moneyness: :math:`(N, *)`
             - time_to_maturity: :math:`(N, *)`
-            - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             torch.Tensor
         """
-        s, m, t, p = map(
-            torch.as_tensor, (log_moneyness, max_log_moneyness, time_to_maturity, price)
+        return find_implied_volatility(
+            self.price,
+            price=price,
+            log_moneyness=log_moneyness,
+            max_log_moneyness=max_log_moneyness,
+            time_to_maturity=time_to_maturity,
+            precision=precision,
         )
-        pricer = lambda volatility: self.price(s, m, t, volatility)
-        return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_attr_and_docstring(BSAmericanBinaryOption, "inputs", BSModuleMixin.inputs)
-set_attr_and_docstring(BSAmericanBinaryOption, "forward", BSModuleMixin.forward)
+_set_attr_and_docstring(BSAmericanBinaryOption, "inputs", BSModuleMixin.inputs)
+_set_attr_and_docstring(BSAmericanBinaryOption, "forward", BSModuleMixin.forward)
