@@ -1,8 +1,8 @@
 import torch
 from torch import Tensor
 
-from pfhedge._utils.bisect import bisect
-from pfhedge._utils.doc import set_attr_and_docstring
+from pfhedge._utils.bisect import find_implied_volatility
+from pfhedge._utils.doc import _set_attr_and_docstring
 from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
@@ -18,18 +18,19 @@ class BSEuropeanOption(BSModuleMixin):
     Shape:
         - Input: :math:`(N, *, 3)` where
           :math:`*` means any number of additional dimensions.
-          See ``inputs`` for the names of input features.
+          See :meth:`inputs` for the names of input features.
         - Output: :math:`(N, *, 1)`.
           All but the last dimension are the same shape as the input.
 
-    .. seealso ::
+    .. seealso::
 
         - :class:`pfhedge.nn.BlackScholes`:
           Initialize Black-Scholes formula module from a derivative.
 
-    Examples:
+    References:
+        - John C. Hull, 2003. Options futures and other derivatives. Pearson.
 
-        The ``forward`` method returns delta of the derivative.
+    Examples:
 
         >>> from pfhedge.nn import BSEuropeanOption
         >>>
@@ -44,9 +45,6 @@ class BSEuropeanOption(BSModuleMixin):
         tensor([[0.4497],
                 [0.5126],
                 [0.5752]])
-
-    References:
-        - John C. Hull, 2003. Options futures and other derivatives. Pearson.
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
@@ -102,7 +100,7 @@ class BSEuropeanOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
 
@@ -129,7 +127,7 @@ class BSEuropeanOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         if not self.call:
             raise ValueError(
@@ -160,7 +158,7 @@ class BSEuropeanOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         s, t, v = map(torch.as_tensor, (log_moneyness, time_to_maturity, volatility))
 
@@ -198,13 +196,17 @@ class BSEuropeanOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns
-            Tensor
+            torch.Tensor
         """
-        s, t, p = map(torch.as_tensor, (log_moneyness, time_to_maturity, price))
-        pricer = lambda v: self.price(s, t, v)
-        return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
+        return find_implied_volatility(
+            self.price,
+            price=price,
+            log_moneyness=log_moneyness,
+            time_to_maturity=time_to_maturity,
+            precision=precision,
+        )
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_attr_and_docstring(BSEuropeanOption, "inputs", BSModuleMixin.inputs)
-set_attr_and_docstring(BSEuropeanOption, "forward", BSModuleMixin.forward)
+_set_attr_and_docstring(BSEuropeanOption, "inputs", BSModuleMixin.inputs)
+_set_attr_and_docstring(BSEuropeanOption, "forward", BSModuleMixin.forward)
