@@ -4,9 +4,9 @@ import torch
 from torch import Tensor
 
 import pfhedge.autogreek as autogreek
-from pfhedge._utils.bisect import bisect
-from pfhedge._utils.doc import set_attr_and_docstring
-from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.bisect import find_implied_volatility
+from pfhedge._utils.doc import _set_attr_and_docstring
+from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
@@ -22,18 +22,18 @@ class BSEuropeanBinaryOption(BSModuleMixin):
     Shape:
         - Input: :math:`(N, *, 3)`, where
           :math:`*` means any number of additional dimensions.
-          See :func:`inputs` for the names of input features.
-        - Output: :math:`(N, *, 1)` Delta of the derivative.
+          See :meth:`inputs` for the names of input features.
+        - Output: :math:`(N, *, 1)`.
           All but the last dimension are the same shape as the input.
 
     .. seealso ::
-
         - :class:`pfhedge.nn.BlackScholes`:
           Initialize Black-Scholes formula module from a derivative.
 
-    Examples:
+    References:
+        - John C. Hull, 2003. Options futures and other derivatives. Pearson.
 
-        The ``forward`` method returns delta of the derivative.
+    Examples:
 
         >>> from pfhedge.nn import BSEuropeanBinaryOption
         >>>
@@ -48,9 +48,6 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         tensor([[6.2576],
                 [6.3047],
                 [6.1953]])
-
-    References:
-        John C. Hull, 2003. Options futures and other derivatives. Pearson.
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
@@ -191,17 +188,20 @@ class BSEuropeanBinaryOption(BSModuleMixin):
         Shape:
             - log_moneyness: :math:`(N, *)`
             - time_to_maturity: :math:`(N, *)`
-            - volatility: :math:`(N, *)`
             - output: :math:`(N, *)`
 
         Returns:
             torch.Tensor
         """
-        s, t, p = map(torch.as_tensor, (log_moneyness, time_to_maturity, price))
-        pricer = lambda v: self.price(s, t, v)
-        return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
+        return find_implied_volatility(
+            self.price,
+            price=price,
+            log_moneyness=log_moneyness,
+            time_to_maturity=time_to_maturity,
+            precision=precision,
+        )
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_docstring(BSEuropeanBinaryOption, "inputs", BSModuleMixin.inputs)
-set_attr_and_docstring(BSEuropeanBinaryOption, "forward", BSModuleMixin.forward)
+_set_docstring(BSEuropeanBinaryOption, "inputs", BSModuleMixin.inputs)
+_set_attr_and_docstring(BSEuropeanBinaryOption, "forward", BSModuleMixin.forward)
