@@ -5,9 +5,9 @@ import torch
 from torch import Tensor
 
 import pfhedge.autogreek as autogreek
-from pfhedge._utils.bisect import bisect
-from pfhedge._utils.doc import set_attr_and_docstring
-from pfhedge._utils.doc import set_docstring
+from pfhedge._utils.bisect import find_implied_volatility
+from pfhedge._utils.doc import _set_attr_and_docstring
+from pfhedge._utils.doc import _set_docstring
 from pfhedge._utils.str import _format_float
 
 from ._base import BSModuleMixin
@@ -23,18 +23,20 @@ class BSLookbackOption(BSModuleMixin):
     Shape:
         - Input: :math:`(N, *, 4)` where
           :math:`*` means any number of additional dimensions.
-          See :func:`inputs` for the names of input features.
+          See :meth:`inputs` for the names of input features.
         - Output: :math:`(N, *, 1)`.
           All but the last dimension are the same shape as the input.
 
-    .. seealso ::
+    .. seealso::
 
         - :class:`pfhedge.nn.BlackScholes`:
           Initialize Black-Scholes formula module from a derivative.
 
-    Examples:
+    References:
+        - Conze, A., 1991. Path dependent options: The case of lookback options.
+          The Journal of Finance, 46(5), pp.1893-1907.
 
-        The ``forward`` method returns delta of the derivative.
+    Examples:
 
         >>> from pfhedge.nn import BSLookbackOption
         >>>
@@ -49,10 +51,6 @@ class BSLookbackOption(BSModuleMixin):
         tensor([[0.9208],
                 [1.0515],
                 [1.0515]])
-
-    References:
-        - Conze, A., 1991. Path dependent options: The case of lookback options.
-          The Journal of Finance, 46(5), pp.1893-1907.
     """
 
     def __init__(self, call: bool = True, strike: float = 1.0):
@@ -120,7 +118,7 @@ class BSLookbackOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         s, m, t, v = map(
             torch.as_tensor,
@@ -178,7 +176,7 @@ class BSLookbackOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         return autogreek.delta(
             self.price,
@@ -215,7 +213,7 @@ class BSLookbackOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
         return autogreek.gamma(
             self.price,
@@ -252,15 +250,18 @@ class BSLookbackOption(BSModuleMixin):
             - output: :math:`(N, *)`
 
         Returns:
-            Tensor
+            torch.Tensor
         """
-        s, m, t, p = map(
-            torch.as_tensor, (log_moneyness, max_log_moneyness, time_to_maturity, price)
+        return find_implied_volatility(
+            self.price,
+            price=price,
+            log_moneyness=log_moneyness,
+            max_log_moneyness=max_log_moneyness,
+            time_to_maturity=time_to_maturity,
+            precision=precision,
         )
-        pricer = lambda volatility: self.price(s, m, t, volatility)
-        return bisect(pricer, p, lower=0.001, upper=1.000, precision=precision)
 
 
 # Assign docstrings so they appear in Sphinx documentation
-set_docstring(BSLookbackOption, "inputs", BSModuleMixin.inputs)
-set_attr_and_docstring(BSLookbackOption, "forward", BSModuleMixin.forward)
+_set_docstring(BSLookbackOption, "inputs", BSModuleMixin.inputs)
+_set_attr_and_docstring(BSLookbackOption, "forward", BSModuleMixin.forward)
