@@ -33,13 +33,18 @@ TensorOrFloat = Union[Tensor, float]
 class Hedger(Module):
     """Module to hedge and price derivatives.
 
+    References:
+        - Buehler, H., Gonon, L., Teichmann, J. and Wood, B., 2019.
+          Deep hedging. Quantitative Finance, 19(8), pp.1271-1291.
+          [arXiv:`1802.03042 <https://arxiv.org/abs/1802.03042>`_ [q-fin]]
+
     Args:
         model (torch.nn.Module): Hedging model to compute the hedge ratio at the
             next time step from the input features at the current time step.
-            The input and output shapes should be :math:`(N, H_\\text{in})` and
+            The input and output shapes should be :math:`(N, F)` and
             :math:`(N, H)` respectively, where
             :math:`N` stands for the number simulated paths of the asset prices and
-            :math:`H_\\text{in}` is the number of input features (``len(inputs)``), and
+            :math:`F` is the number of input features (``len(inputs)``), and
             :math:`H` is the number of hedging instruments.
         inputs (list[str|Feature]): List of the names of the input features that
             will be fed to the model.
@@ -49,9 +54,9 @@ class Hedger(Module):
             Default: :class:`pfhedge.nn.EntropicRiskMeasure()` .
 
     Shape:
-        - input: :math:`(N, H_{\\text{in}})` where
+        - input: :math:`(N, F)` where
           :math:`N` is the number of simulated paths and
-          :math:`H_{\\text{in}}` is the number of input features.
+          :math:`F` is the number of input features.
         - output: :math:`(N, H)` where
           :math:`H` is the number of hedging instruments.
 
@@ -317,18 +322,17 @@ class Hedger(Module):
         n_paths: int = 1000,
         init_state: Optional[Tuple[TensorOrFloat, ...]] = None,
     ) -> Tensor:
-        """Returns the profit and loss distribution after hedging.
+        """Returns the terminal portfolio value after hedging a given derivative.
 
-        A hedger sells the derivative to its customer and obliges to settle the payoff
-        at maturity. The dealer hedges the risk of this liability by trading
-        the underlying instrument of the derivative based on ``self.model``.
-        The resulting profit and loss is obtained by adding up the payoff to the
-        customer, capital gains from the underlying asset, and the transaction cost.
+        This method simulates the derivative, computes the hedge ratio, and
+        computes the terminal portfolio value.
+        See :func:`pfhedge.nn.functional.terminal_value` for the expression of the
+        terminal portyol value after hedging a derivative.
 
         Args:
             derivative (Derivative): The derivative to hedge.
-            hedge (Instrument, optional): The hedging instrument.
-                If ``None`` (default), use ``derivative.underlier``.
+            hedge (list[Instrument], optional): The hedging instruments.
+                If ``None`` (default), use ``[derivative.underlier]``.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
             init_state (tuple[torch.Tensor | float], optional): The initial state of
@@ -375,10 +379,16 @@ class Hedger(Module):
         init_state: Optional[Tuple[TensorOrFloat, ...]] = None,
         enable_grad: bool = True,
     ) -> Tensor:
-        """Returns the loss of the profit and loss distribution after hedging.
+        """Returns the value of the criterion for the terminal portfolio value
+        after hedging a given derivative.
+
+        This method basically computes ``self.criterion(pnl)``
+        where ``pnl`` is given by :meth:`compute_pnl`.
 
         Args:
             derivative (Derivative): The derivative to hedge.
+            hedge (list[Instrument], optional): The hedging instruments.
+                If ``None`` (default), use ``[derivative.underlier]``.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
             n_times (int, default=1): If ``n_times > 1``, returns the ensemble mean
@@ -445,13 +455,20 @@ class Hedger(Module):
         optimizer=Adam,
         init_state: Optional[Tuple[TensorOrFloat, ...]] = None,
         verbose: bool = True,
-    ) -> List[float]:
-        """Train the hedging model to hedge the given derivative.
+        validation: bool = True,
+    ) -> Optional[List[float]]:
+        """Fit the hedging model to hedge a given derivative.
 
-        It returns the trade history, that is, validation loss after each simulation.
+        The training is performed so that the hedger minimizes ``criterion(pnl)``
+        where ``pnl`` is given by :meth:`compute_pnl`.
+
+        It returns the training history, that is,
+        validation loss after each simulation.
 
         Args:
             derivative (Derivative): The derivative to hedge.
+            hedge (list[Instrument], optional): The hedging instruments.
+                If ``None`` (default), use ``[derivative.underlier]``.
             n_epochs (int, default=100): Number of Monte-Carlo simulations.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
@@ -465,6 +482,8 @@ class Hedger(Module):
                 If ``None`` (default), sensible default value is used.
             verbose (bool, default=True): If ``True``, print progress of the training to
                 standard output.
+            validation (bool, default=True): If ``False``, skip the computation of the
+                validation loss and returns ``None``.
 
         Returns:
             list[float]
@@ -532,13 +551,14 @@ class Hedger(Module):
             optimizer.step()
 
             # Compute validation loss
-            self.eval()
-            loss = compute_loss(n_times=n_times, enable_grad=False)
-            history.append(loss.item())
+            if validation:
+                self.eval()
+                loss = compute_loss(n_times=n_times, enable_grad=False)
+                history.append(loss.item())
 
-            progress.desc = "Loss=" + _format_float(float(loss.item()))
+                progress.desc = "Loss=" + _format_float(float(loss.item()))
 
-        return history
+        return history if validation else None
 
     def price(
         self,
@@ -553,6 +573,8 @@ class Hedger(Module):
 
         Args:
             derivative (Derivative): The derivative to price.
+            hedge (list[Instrument], optional): The hedging instruments.
+                If ``None`` (default), use ``[derivative.underlier]``.
             n_paths (int, default=1000): The number of simulated price paths of the
                 underlying instrument.
             n_times (int, default=1): If ``n_times > 1``, returns the ensemble mean of
