@@ -19,7 +19,7 @@ class WhalleyWilmott(Module):
     asymptotically small transaction cost, European option, and exponential utility.
     The half-width of the no-transaction band is given by
 
-    .. math ::
+    .. math::
 
         w = \\left( \\frac{3 c \\Gamma^2 S}{2 a} \\right)^{1 / 3} \,,
 
@@ -28,14 +28,21 @@ class WhalleyWilmott(Module):
     :math:`S` is the spot price of the underlying instrument, and
     :math:`a` is the risk-aversion coefficient of the exponential utility.
 
-    .. note ::
-
+    Note:
         A backward computation for this module generates ``nan``
         if the :math:`\\Gamma` of the derivative is too small.
         This is because the output is proportional to :math:`\\Gamma^{2 / 3}`
         of which gradient diverges for :math:`\\Gamma \\to 0`.
         A ``dtype`` with higher precision may alleviate this problem.
 
+    References:
+        - Davis, M.H., Panas, V.G. and Zariphopoulou, T., 1993.
+          European option pricing with transaction costs.
+          SIAM Journal on Control and Optimization, 31(2), pp.470-493.
+        - Whalley, A.E. and Wilmott, P., An asymptotic analysis of an optimal hedging
+          model for option pricing with transaction costs. Mathematical Finance,
+          1997, 7, 307–324.
+
     Args:
         derivative (:class:`pfhedge.instruments.Derivative`): Derivative to hedge.
         a (float, default=1.0): Risk aversion parameter in exponential utility.
@@ -44,7 +51,7 @@ class WhalleyWilmott(Module):
         - Input: :math:`(N, *, H_{\\text{in}})` where
           :math:`*` means any number of additional dimensions and
           :math:`H_{\\text{in}}` is the number of input features.
-          See :func:`inputs()` for the names of input features.
+          See :meth:`inputs()` for the names of input features.
         - Output: :math:`(N, *, 1)`.
 
     Examples:
@@ -91,11 +98,6 @@ class WhalleyWilmott(Module):
                 [0.5126],
                 [0.5752],
                 [0.7945]])
-
-    References:
-        - Whalley, A.E. and Wilmott, P., An asymptotic analysis of an optimal hedging
-          model for option pricing with transaction costs. Mathematical Finance,
-          1997, 7, 307–324.
     """
 
     def __init__(self, derivative, a: float = 1.0) -> None:
@@ -137,7 +139,7 @@ class WhalleyWilmott(Module):
             - Input: :math:`(N, *, H_{\\text{in}} - 1)` where
               :math:`*` means any number of additional dimensions and
               :math:`H_{\\text{in}}` is the number of input features.
-              See :func:`inputs()` for the names of input features.
+              See :meth:`inputs()` for the names of input features.
             - Output: :math:`(N, *, 1)`
 
         Returns:
